pub struct CsiConfig {Show 14 fields
pub enable: u32,
pub acquire_csi_legacy: u32,
pub acquire_csi_force_lltf: bool,
pub acquire_csi_ht20: u32,
pub acquire_csi_ht40: u32,
pub acquire_csi_vht: bool,
pub acquire_csi_su: u32,
pub acquire_csi_mu: u32,
pub acquire_csi_dcm: u32,
pub acquire_csi_beamformed: u32,
pub acquire_csi_he_stbc: u32,
pub val_scale_cfg: u32,
pub dump_ack_en: u32,
pub reserved: u32,
}csi and unstable only.Expand description
Channel state information (CSI) configuration.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
enable: u32Enable to acquire CSI.
acquire_csi_legacy: u32Enable to acquire L-LTF.
acquire_csi_force_lltf: boolEnable to acquire L-LTF.
acquire_csi_ht20: u32Enable to acquire HT-LTF when receiving an HT20 PPDU.
acquire_csi_ht40: u32Enable to acquire HT-LTF when receiving an HT40 PPDU.
acquire_csi_vht: boolEnable to acquire VHT-LTF when receiving an VHT20 PPDU.
acquire_csi_su: u32Enable to acquire HE-LTF when receiving an HE20 SU PPDU.
acquire_csi_mu: u32Enable to acquire HE-LTF when receiving an HE20 MU PPDU.
acquire_csi_dcm: u32Enable to acquire HE-LTF when receiving an HE20 DCM applied PPDU.
acquire_csi_beamformed: u32Enable to acquire HE-LTF when receiving an HE20 Beamformed applied PPDU.
acquire_csi_he_stbc: u32When receiving an STBC applied HE PPDU, 0- acquire the complete HE-LTF1, 1- acquire the complete HE-LTF2, 2- sample evenly among the HE-LTF1 and HE-LTF2.
val_scale_cfg: u32Value 0-3.
dump_ack_en: u32Enable to dump 802.11 ACK frame, default disabled.
reserved: u32Reserved.